@@ -81,10 +81,14 @@ class Connector(connector.SQLConnector):
 
     def _list_databases(self):
         databases = []
+        raw_databases = list(self._query('show databases'))
+
         # The 'show databases' sentece includes also default databases SNOWFLAKE and SNOWFLAKE_SAMPLE_DATA.
-        # Apparently, there's no way to filter out those databases from the result set. So we'll just query the information_schema.
-        for database in list(self._query('select distinct database_name from information_schema.databases where database_name not in (\'SNOWFLAKE\',\'SNOWFLAKE_SAMPLE_DATA\')')):
-            databases.append(connector.Scope(name=database['DATABASE_NAME'], value=database['DATABASE_NAME']))
+        # Apparently, there's no way to filter out those databases from the result set. So we'll filter them manually.
+        filtered_databases =  list(filter(lambda d: d['name'] not in ('SNOWFLAKE', 'SNOWFLAKE_SAMPLE_DATA'), raw_databases))
+
+        for database in filtered_databases:
+            databases.append(connector.Scope(name=database['name'], value=database['name']))
         databases.sort(key=lambda database: database.name)
         return databases
 
